@@ -16,5 +16,15 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-char *deparseMac(unsigned char *mac);
-void hexdump(unsigned char *buf,int size);
+#ifndef __AS_UTILS_H
+#define __AS_UTILS_H
+
+void *malloc_r(int size);
+void *calloc_r(int nmemb, int size);
+void free_r();
+
+void loadOpts(void);
+void saveOpts(void);
+
+#endif
+
